#[repr(C)]pub struct SharedVmoIoTransmitRequest {
pub buffer: SharedVmoBuffer,
}Expand description
The wire type corresponding to SharedVmoIoTransmitRequest.
Fields
buffer: SharedVmoBufferTrait Implementations
Sourcefn clone(&self) -> SharedVmoIoTransmitRequest
fn clone(&self) -> SharedVmoIoTransmitRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SharedVmoIoTransmitRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SharedVmoIoTransmitRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SharedVmoIoTransmitRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SharedVmoIoTransmitRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SharedVmoIoTransmitRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SharedVmoIoTransmitRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourcefn from_wire(wire: SharedVmoIoTransmitRequest) -> Self
fn from_wire(wire: SharedVmoIoTransmitRequest) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourcefn from_wire_ref(wire: &SharedVmoIoTransmitRequest) -> Self
fn from_wire_ref(wire: &SharedVmoIoTransmitRequest) -> Self
Converts the given reference to this type.
Sourcetype Natural = SharedVmoIoTransmitRequest
type Natural = SharedVmoIoTransmitRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourcetype Narrowed<'de> = SharedVmoIoTransmitRequest
type Narrowed<'de> = SharedVmoIoTransmitRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.